@@ -171,7 +171,7 @@ namespace Rivet {
     // If there are no weights, add a nominal one
     if (_weightNames.empty()) {
       _weightNames.push_back("");
-      _rivetDefaultWeightIdx = _defaultWeightIdx = 0;
+      _customDefaultWeightIdx =_rivetDefaultWeightIdx = _defaultWeightIdx = 0;
       _weightIndices = { 0 };
       return;
     }
@@ -564,7 +564,7 @@ namespace Rivet {
         if ( !analysis->info().validOption(opt[0], opt[1]) )
           MSG_WARNING("Setting the option '" << opt[0] << "' to '"
                       << opt[1] << "' for " << analysisname
-                      << " has not been declared in the info file "
+                      << " has not been declared in the info file"
                       << " and may be ignored in the analysis.");
         opts[opt[0]] = opt[1];
       }
@@ -727,7 +727,7 @@ namespace Rivet {
     std::cout << std::endl;
 
     if (allaos.empty()) {
-      cerr << "Insuffient pre-finalize AOs to do a reentrant run!" << endl;
+      cerr << "Insufficient pre-finalize AOs to do a reentrant run!" << endl;
       exit(1);
     }
 
@@ -751,7 +751,7 @@ namespace Rivet {
       xsec->addPoint(xs, xserr);
     }
 
-    MSG_INFO("Rerunning finalize ...");
+    MSG_INFO("Re-running finalize ...");
 
     // initialise analyses and load merged AOs back into memory
     // set unscale to true if equiv is false
